Origin
------

.. autosimple:: swh.web.api.views.origin.api_origin

.. autosimple:: swh.web.api.views.origin.api_origin_search

.. autosimple:: swh.web.api.views.origin.api_origin_visits

.. autosimple:: swh.web.api.views.origin.api_origin_visit

.. autosimple:: swh.web.api.views.origin.api_origin_visit

.. autosimple:: swh.web.save_code_now.api_views.api_save_origin

.. autosimple:: swh.web.save_origin_webhooks.bitbucket.api_origin_save_webhook_bitbucket

.. autosimple:: swh.web.save_origin_webhooks.gitea.api_origin_save_webhook_gitea

.. autosimple:: swh.web.save_origin_webhooks.github.api_origin_save_webhook_github

.. autosimple:: swh.web.save_origin_webhooks.gitlab.api_origin_save_webhook_gitlab

.. autosimple:: swh.web.save_origin_webhooks.sourceforge.api_origin_save_webhook_sourceforge
